"""Added Dxf model

Revision ID: 5ad8b58df646
Revises: 
Create Date: 2015-06-02 22:08:03.996137

"""

# revision identifiers, used by Alembic.
revision = '5ad8b58df646'
down_revision = None
branch_labels = None
depends_on = None



from alembic import op
import sqlalchemy as sa
import geoalchemy2
from sqlalchemy.dialects import postgresql



def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    pass
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    pass
    ### end Alembic commands ###
